camelot.camelot.model.synchronization.Synchronized

Package camelot :: Package camelot :: Package model :: Module synchronization :: Class Synchronized |
[hide private]
[frames] | no frames]

# Class Synchronized

source code

Class Variables | [hide private]
| database = `Field(Unicode(30), index= True)`
| tablename = `Field(Unicode(30), index= True)`
| primary_key = `Field(Integer(), index= True)`
| last_update = `Field(DateTime(), index= True, default= datetime`...``

Class Variable Details | [hide private]

  ### last_update Value:
      Field(DateTime(), index= True, default= datetime.datetime.now, onupdat
      e= datetime.datetime.now)